@@ -18,7 +18,7 @@
  */
 
 #include "mainwindow.h"
-#include "projectmodel.h"
+#include "../common/projectmodel.h"
 
 #include <QAction>
 #include <QApplication>
@@ -60,7 +60,7 @@ public:
     explicit ItemTypeComboBox( QWidget* parent = nullptr );
 
     KGantt::ItemType itemType() const;
-public slots:
+public Q_SLOTS:
     void setItemType( KGantt::ItemType typ );
 };
 
@@ -291,6 +291,7 @@ MainWindow::MainWindow( QWidget* parent )
 
     toolsMenu->addAction( tr( "&New Item" ), this, SLOT(slotToolsNewItem()) );
     toolsMenu->addAction( tr( "&Add Item" ), this, SLOT(slotToolsAppendItem()) );
+    toolsMenu->addAction( tr( "&Remove Item" ), this, SLOT(slotToolsRemoveItem()) );
     toolsMenu->addSeparator();
     QMenu *alignMenu = toolsMenu->addMenu( tr( "Ali&gn" ) );
     alignMenu->addAction( tr( "&Left" ), this, SLOT(slotAlignLeft()) );
@@ -426,6 +427,15 @@ void MainWindow::slotToolsAppendItem()
     }
 }
 
+void MainWindow::slotToolsRemoveItem()
+{
+    QModelIndex idx = m_view->selectionModel()->currentIndex();
+    if ( idx.isValid() ) {
+        qDebug() << "MainWindow::slotToolsRemoveItem" << idx;
+        m_model->removeRows( idx.row(), 1, idx.parent() );
+    }
+}
+
 void MainWindow::slotCollapseAll()
 {
     // don't use the treeview's collapseAll/expandAll methods but use the one provided by the
