@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef DERIVEDADDLEGENDDIALOG_H
@@ -27,7 +27,7 @@ class DerivedAddLegendDialog : public QDialog, public Ui::AddLegendDialog
     Q_OBJECT
 
 public:
-    DerivedAddLegendDialog( QWidget* parent = 0 );
+    DerivedAddLegendDialog( QWidget* parent = nullptr );
 };
 
 #endif // DERIVEDADDLEGENDDIALOG_H
