@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "mainwindow.h"
@@ -36,7 +36,7 @@ using namespace KChart;
 class EmptyModel : public QAbstractItemModel
 {
 public:
-    EmptyModel( QObject* parent = 0 )
+    EmptyModel( QObject* parent = nullptr )
         : QAbstractItemModel( parent )
     {
         //qDebug() << "EmptyModel::EmptyModel()";
@@ -47,14 +47,14 @@ public:
         //qDebug() << "EmptyModel::~EmptyModel()";
     }
 
-    int columnCount( const QModelIndex& parent = QModelIndex() ) const Q_DECL_OVERRIDE
+    int columnCount( const QModelIndex& parent = QModelIndex() ) const override
     {
         Q_UNUSED( parent );
         //qDebug() << "EmptyModel::columnCount(...)";
         return 0;
     }
 
-    int rowCount( const QModelIndex& parent = QModelIndex() ) const Q_DECL_OVERRIDE
+    int rowCount( const QModelIndex& parent = QModelIndex() ) const override
     {
         Q_UNUSED( parent );
         //qDebug() << "EmptyModel::rowCount(...)";
@@ -64,7 +64,7 @@ public:
 
     // NOTE: The following method will not be called by KD Chart,
     //       because the model is returning 0 for columnCount() / rowCount().
-    QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const Q_DECL_OVERRIDE
+    QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const override
     {
         Q_UNUSED( role );
         qDebug() << "EmptyModel::data(" << index.row() << index.column() << ")";
@@ -72,7 +72,7 @@ public:
         return QVariant();
     }
 
-    QModelIndex index( int row, int column, const QModelIndex& parent = QModelIndex() ) const Q_DECL_OVERRIDE
+    QModelIndex index( int row, int column, const QModelIndex& parent = QModelIndex() ) const override
     {
         Q_UNUSED( row );
         Q_UNUSED( column );
@@ -81,7 +81,7 @@ public:
         return QModelIndex();
     }
 
-    QModelIndex parent( const QModelIndex& parent ) const Q_DECL_OVERRIDE
+    QModelIndex parent( const QModelIndex& parent ) const override
     {
         Q_UNUSED( parent );
         //qDebug() << "EmptyModel::parent(...)";
