@@ -65,7 +65,7 @@ MainWidget::MainWidget()
     m_functionSelector << m_controls.sineRadio << m_controls.triangleRadio << m_controls.squareRadio
                        << m_controls.noiseRadio << m_controls.oneDivSineRadio
                        << m_controls.sineOneDivRadio;
-    foreach ( QRadioButton* r, m_functionSelector ) {
+    for ( QRadioButton* r : qAsConst(m_functionSelector) ) {
         connect( r, SIGNAL(toggled(bool)), SLOT(functionToggled(bool)) );
     }
 
@@ -74,7 +74,7 @@ MainWidget::MainWidget()
 
     // order matters again
     m_addPointsButtons << m_controls.add1kButton << m_controls.add10kButton << m_controls.add100kButton;
-    foreach ( QPushButton* b, m_addPointsButtons ) {
+    for ( QPushButton* b : qAsConst(m_addPointsButtons) ) {
         connect( b, SIGNAL(clicked(bool)), SLOT(addPointsButtonClicked()) );
     }
 }
