@@ -38,7 +38,7 @@ public:
 
 
 
-private slots:
+private Q_SLOTS:
     void on_zoomFactorSB_valueChanged( double factor );
     void on_adjustGridCB_toggled( bool checked );
     void on_rubberBandZoomCB_toggled( bool checked );
