@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef DATASETSETTINGS_H
@@ -32,7 +32,7 @@ class DatasetSettings : public QWidget
     Q_PROPERTY( int datasetCount READ datasetCount WRITE setDatasetCount NOTIFY datasetCountChanged() )
 
 public:
-    explicit DatasetSettings( KChart::Chart *chart, QWidget *parent = 0 );
+    explicit DatasetSettings( KChart::Chart *chart, QWidget *parent = nullptr );
     ~DatasetSettings();
     int datasetCount() const;
 public Q_SLOTS:
