@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef GRADIENTDIALOG_H
@@ -29,11 +29,11 @@ class GradientDialog : public QDialog
     Q_PROPERTY( QGradient gradient READ gradient WRITE setGradient NOTIFY gradientChanged() )
 
 public:
-    explicit GradientDialog( QWidget *parent = 0 );
+    explicit GradientDialog( QWidget *parent = nullptr );
     ~GradientDialog();
     QGradient gradient() const;
     void setGradient( const QGradient &gradient );
-    static QGradient getGradient( const QGradient &gradient, QWidget *parent = 0, const QString &title = QString() );
+    static QGradient getGradient( const QGradient &gradient, QWidget *parent = nullptr, const QString &title = QString() );
 
 Q_SIGNALS:
     void gradientChanged();
