@@ -31,7 +31,7 @@ using namespace KChart;
 
 class TestAxisOwnership: public QObject {
   Q_OBJECT
-private slots:
+private Q_SLOTS:
 
   void initTestCase()
   {
