@@ -30,7 +30,7 @@ using namespace KChart;
 
 class TestBarDiagrams: public QObject {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
 
     void initTestCase()
     {
