@@ -33,7 +33,7 @@ using namespace KChart;
 
 class TestLegends: public QObject {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
 
     void initTestCase()
     {
