@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef KCHARTPERCENTLINEDIAGRAM_P_H
@@ -29,9 +29,9 @@ namespace KChart {
     public:
         explicit PercentLineDiagram( LineDiagram* );
         virtual ~PercentLineDiagram() {}
-        LineDiagram::LineType type() const Q_DECL_OVERRIDE;
-        const QPair<QPointF,  QPointF> calculateDataBoundaries() const Q_DECL_OVERRIDE;
-        void paint( PaintContext* ctx ) Q_DECL_OVERRIDE;
+        LineDiagram::LineType type() const override;
+        const QPair<QPointF,  QPointF> calculateDataBoundaries() const override;
+        void paint( PaintContext* ctx ) override;
     };
 
 }
