@@ -14,16 +14,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+#include "KChartStackedBarDiagram_p.h"
 #include <QModelIndex>
 
 #include "KChartBarDiagram.h"
 #include "KChartTextAttributes.h"
 #include "KChartAttributesModel.h"
 #include "KChartAbstractCartesianDiagram.h"
-#include "KChartStackedBarDiagram_p.h"
 
 using namespace KChart;
 
@@ -149,10 +149,15 @@ void StackedBarDiagram::paint( PaintContext* ctx )
         qreal offset = spaceBetweenGroups;
         if ( ba.useFixedBarWidth() )
             offset -= ba.fixedBarWidth();
-        
-        if ( offset < 0 )
-            offset = 0;
 
+        CartesianCoordinatePlane *plane = static_cast<CartesianCoordinatePlane*>(ctx->coordinatePlane());
+        if (plane->isHorizontalRangeReversed()) {
+            if (offset > 0) {
+                offset = 0;
+            }
+        } else if ( offset < 0 ) {
+            offset = 0;
+        }
         for ( int row = 0; row < rowCount; ++row )
         {
             const CartesianDiagramDataCompressor::CachePosition position( row, col );
@@ -201,7 +206,7 @@ void StackedBarDiagram::paint( PaintContext* ctx )
                 const qreal barHeight = previousPoint.y() - point.y();
 
                 const QRectF rect( point, QSizeF( barWidth , barHeight ) );
-                m_private->addLabel( &lpc, index, 0, PositionPoints( rect ), Position::North,
+                m_private->addLabel( &lpc, index, nullptr, PositionPoints( rect ), Position::North,
                                      Position::South, value );
                 paintBars( ctx, index, rect, maxDepth );
             }
