@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "KChartLeveyJenningsGrid.h"
@@ -192,7 +192,7 @@ void LeveyJenningsGrid::calculateStepWidth(
     Q_ASSERT_X ( granularities.count(), "CartesianGrid::calculateStepWidth",
                  "Error: The list of GranularitySequence values is empty." );
     QList<qreal> list( granularities );
-    qSort( list );
+    std::sort(list.begin(), list.end());
 
     const qreal start = qMin( start_, end_);
     const qreal end   = qMax( start_, end_);
