@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef PLOTTERDIAGRAMCOMPRESSOR_P_H
@@ -22,8 +22,8 @@
 
 #include "KChartPlotterDiagramCompressor.h"
 
-#include <QtCore/QPointF>
-#include <QtCore/QDateTime>
+#include <QPointF>
+#include <QDateTime>
 
 typedef QPair< QPointF, QPointF > Boundaries;
 
