@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef CHARTGRAPHICSITEM_H
@@ -39,7 +39,7 @@ namespace KChart {
 
         int row() const { return m_row; }
         int column() const { return m_column; }
-        int type() const Q_DECL_OVERRIDE { return Type; }
+        int type() const override { return Type; }
 
     private:
         int m_row;
