@@ -14,11 +14,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef KCHARTABSTRCOORDINATEPLANE_P_H
-#define KCHARTABSTRCOORDINATEPLANE_P_H
+#ifndef KCHARTABSTRACTCOORDINATEPLANE_P_H
+#define KCHARTABSTRACTCOORDINATEPLANE_P_H
 
 //
 //  W A R N I N G
