@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef KCHARTCHART_P_H
@@ -63,14 +63,14 @@ class CartesianAxis;
  */
 struct PlaneInfo {
     PlaneInfo()
-        : referencePlane( 0 ),
+        : referencePlane( nullptr ),
           horizontalOffset( 1 ),
           verticalOffset( 1 ),
-          gridLayout( 0 ),
-          topAxesLayout( 0 ),
-          bottomAxesLayout( 0 ),
-          leftAxesLayout( 0 ),
-          rightAxesLayout( 0 )
+          gridLayout( nullptr ),
+          topAxesLayout( nullptr ),
+          bottomAxesLayout( nullptr ),
+          leftAxesLayout( nullptr ),
+          rightAxesLayout( nullptr )
     {}
     AbstractCoordinatePlane *referencePlane;
     int horizontalOffset;
@@ -85,11 +85,11 @@ struct PlaneInfo {
 struct LayoutGraphNode
 {
     LayoutGraphNode()
-        : diagramPlane( 0 )
-        , leftSuccesor( 0 )
-        , bottomSuccesor( 0 )
-        , sharedSuccesor( 0 )
-        , gridLayout( 0 )
+        : diagramPlane( nullptr )
+        , leftSuccesor( nullptr )
+        , bottomSuccesor( nullptr )
+        , sharedSuccesor( nullptr )
+        , gridLayout( nullptr )
         , topAxesLayout( false )
         , bottomAxesLayout( false )
         , leftAxesLayout( false )
@@ -173,7 +173,7 @@ class Q_DECL_HIDDEN Chart::Private : public QObject
 
         struct AxisInfo {
             AxisInfo()
-                :plane(0)
+                :plane(nullptr)
             {}
             AbstractCoordinatePlane *plane;
         };
