@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "KChartGridAttributes.h"
@@ -91,7 +91,7 @@ GridAttributes & GridAttributes::operator=( const GridAttributes& r )
 
 GridAttributes::~GridAttributes()
 {
-    delete _d; _d = 0;
+    delete _d; _d = nullptr;
 }
 
 
@@ -130,99 +130,33 @@ bool GridAttributes::linesOnAnnotations() const
     return d->linesOnAnnotations;
 }
 
-/**
-  * Specifies the step width to be used for calculating
-  * the grid lines.
-  *
-  * \note Step with can be set for Linear axis calculation mode only,
-  * there is no way to specify a step width for Logarithmic axes.
-  *
-  * By default the GridAttributes class does not use a fixed step width,
-  * but it uses KChartEnums::GranularitySequence_10_20.
-  *
-  * \param stepWidth the step width to be used.
-  * If this parameter is omitted (or set to Zero, resp.)
-  * the automatic step width calculation will be done,
-  * using the granularity sequence specified.
-  * This is the default.
-  *
-  * \sa gridStepWidth, setGranularitySequence
-  */
 void GridAttributes::setGridStepWidth( qreal stepWidth )
 {
     d->stepWidth = stepWidth;
 }
 
-/**
-  * Returns the step width to be used for calculating
-  * the grid lines.
-  *
-  * \sa setGridStepWidth
-  */
 qreal GridAttributes::gridStepWidth() const
 {
     return d->stepWidth;
 }
 
 
-/**
-  * Specifies the sub-step width to be used for calculating
-  * the grid sub-lines.
-  *
-  *
-  * \param subStepWidth the sub-step width to be used.
-  * If this parameter is omitted (or set to Zero, resp.)
-  * the automatic calculation will be done, using the
-  * granularity sequence specified.
-  * This is the default.
-  *
-  * \sa gridSubStepWidth
-  */
 
 void GridAttributes::setGridSubStepWidth( qreal subStepWidth )
 {
     d->subStepWidth = subStepWidth;
 }
 
-/**
-  * Returns the sub-step width to be used for calculating
-  * the sub-grid lines.
-  *
-  * \sa setGridStepWidth
-  */
 qreal GridAttributes::gridSubStepWidth() const
 {
     return d->subStepWidth;
 }
 
-/**
-  * Specifies the granularity sequence to be used for calculating
-  * the grid lines.
-  *
-  * By default the GridAttributes class uses KChartEnums::GranularitySequence_10_20.
-  *
-  * \note Granularity can be set for Linear axis calculation mode only,
-  * there is no way to specify a step width for Logarithmic axes.
-  *
-  * \note The sequence specified by this method is ignored, if
-  * a fixed step width was specified via setStepWidth.
-  *
-  * \param sequence one of the sequences declared in
-  * KChartEnums::GranularitySequence.
-  *
-  * \sa gridGranularitySequence, setStepWidth
-  */
 void GridAttributes::setGridGranularitySequence( KChartEnums::GranularitySequence sequence )
 {
     d->sequence = sequence;
 }
 
-/**
-  * Returns the granularity sequence to be used for calculating
-  * the grid lines.
-  *
-  * \sa setGridGranularitySequence
-  */
 KChartEnums::GranularitySequence GridAttributes::gridGranularitySequence() const
 {
     return d->sequence;
