@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "KChartLayoutItems.h"
@@ -44,14 +44,6 @@
 
 //#define DEBUG_ITEMS_PAINT
 
-/**
-    Inform the item about its widget: This enables the item,
-    to trigger that widget's update, whenever the size of the item's
-    contents has changed.
-
-    Thus, you need to call setParentWidget on every item, that
-    has a non-fixed size.
-  */
 void KChart::AbstractLayoutItem::setParentWidget( QWidget* widget )
 {
     mParent = widget;
@@ -62,18 +54,12 @@ void KChart::AbstractLayoutItem::paintAll( QPainter& painter )
     paint( &painter );
 }
 
-/**
-  * Default impl: Paint the complete item using its layouted position and size.
-  */
 void KChart::AbstractLayoutItem::paintCtx( PaintContext* context )
 {
     if ( context )
         paint( context->painter() );
 }
 
-/**
-    Report changed size hint: ask the parent widget to recalculate the layout.
-  */
 void KChart::AbstractLayoutItem::sizeHintChanged() const
 {
     // This is exactly like what QWidget::updateGeometry does.
@@ -216,7 +202,7 @@ KChart::TextLayoutItem::TextLayoutItem()
     , mText()
     , mTextAlignment( Qt::AlignLeft )
     , mAttributes()
-    , mAutoReferenceArea( 0 )
+    , mAutoReferenceArea( nullptr )
     , mAutoReferenceOrientation( KChartEnums::MeasureOrientationHorizontal )
     , cachedSizeHint() // default this to invalid to force just-in-time calculation before first use of sizeHint()
     , cachedFontSize( 0.0 )
@@ -265,11 +251,6 @@ Qt::Alignment KChart::TextLayoutItem::textAlignment() const
     return mTextAlignment;
 }
 
-/**
-  \brief Use this to specify the text attributes to be used for this item.
-
-  \sa textAttributes
-*/
 void KChart::TextLayoutItem::setTextAttributes( const TextAttributes &a )
 {
     mAttributes = a;
@@ -280,11 +261,6 @@ void KChart::TextLayoutItem::setTextAttributes( const TextAttributes &a )
         mParent->update();
 }
 
-/**
-  Returns the text attributes to be used for this item.
-
-  \sa setTextAttributes
-*/
 KChart::TextAttributes KChart::TextLayoutItem::textAttributes() const
 {
     return mAttributes;
@@ -293,7 +269,7 @@ KChart::TextAttributes KChart::TextLayoutItem::textAttributes() const
 
 Qt::Orientations KChart::TextLayoutItem::expandingDirections() const
 {
-    return 0; // Grow neither vertically nor horizontally
+    return Qt::Orientations(); // Grow neither vertically nor horizontally
 }
 
 QRect KChart::TextLayoutItem::geometry() const
@@ -447,7 +423,7 @@ int KChart::TextLayoutItem::marginWidth() const
 
 int KChart::TextLayoutItem::marginWidth( const QSize& textSize ) const
 {
-    return qMin ( QApplication::style()->pixelMetric( QStyle::PM_ButtonMargin, 0, 0 ),
+    return qMin ( QApplication::style()->pixelMetric( QStyle::PM_ButtonMargin, nullptr, nullptr ),
                   // decrease frame size if the text is small
                   textSize.height() * 2 / 3 );
 }
@@ -637,7 +613,7 @@ KChart::MarkerLayoutItem::MarkerLayoutItem( KChart::AbstractDiagram* diagram,
 
 Qt::Orientations KChart::MarkerLayoutItem::expandingDirections() const
 {
-    return 0; // Grow neither vertically nor horizontally
+    return Qt::Orientations(); // Grow neither vertically nor horizontally
 }
 
 QRect KChart::MarkerLayoutItem::geometry() const
@@ -732,7 +708,7 @@ KChart::LineLayoutItem::LineLayoutItem( KChart::AbstractDiagram* diagram,
 
 Qt::Orientations KChart::LineLayoutItem::expandingDirections() const
 {
-    return 0; // Grow neither vertically nor horizontally
+    return Qt::Orientations(); // Grow neither vertically nor horizontally
 }
 
 QRect KChart::LineLayoutItem::geometry() const
@@ -831,7 +807,7 @@ KChart::LineWithMarkerLayoutItem::LineWithMarkerLayoutItem(
 
 Qt::Orientations KChart::LineWithMarkerLayoutItem::expandingDirections() const
 {
-    return 0; // Grow neither vertically nor horizontally
+    return Qt::Orientations(); // Grow neither vertically nor horizontally
 }
 
 QRect KChart::LineWithMarkerLayoutItem::geometry() const
@@ -891,7 +867,7 @@ KChart::AutoSpacerLayoutItem::AutoSpacerLayoutItem(
 
 Qt::Orientations KChart::AutoSpacerLayoutItem::expandingDirections() const
 {
-    return 0; // Grow neither vertically nor horizontally
+    return Qt::Orientations(); // Grow neither vertically nor horizontally
 }
 
 QRect KChart::AutoSpacerLayoutItem::geometry() const
@@ -927,7 +903,7 @@ static void updateCommonBrush( QBrush& commonBrush, bool& bStart, const KChart::
             ! area.frameAttributes().isVisible() &&
             ba.isVisible() &&
             ba.pixmapMode() == KChart::BackgroundAttributes::BackgroundPixmapModeNone &&
-            ba.brush().gradient() == 0 );
+            ba.brush().gradient() == nullptr );
     if ( bStart ) {
         bStart = false;
         commonBrush = hasSimpleBrush ? ba.brush() : QBrush();
