@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "KChartLineAttributes.h"
@@ -75,7 +75,7 @@ LineAttributes& LineAttributes::operator= ( const LineAttributes& r )
 
 LineAttributes::~LineAttributes()
 {
-    delete _d; _d = 0;
+    delete _d; _d = nullptr;
 }
 
 bool LineAttributes::operator==( const LineAttributes& r ) const
