@@ -14,11 +14,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef KDAB_LIB_FAKES_H
-#define KDAB_LIB_FAKES_H
+#ifndef KCHARTMATH_P_H
+#define KCHARTMATH_P_H
 
 #if defined Q_OS_DARWIN
 #include <math.h>
