@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "KChartModelDataCache_p.h"
@@ -24,7 +24,7 @@
 using namespace KChart::ModelDataCachePrivate;
 
 ModelSignalMapperConnector::ModelSignalMapperConnector( ModelSignalMapper& mapper )
-    : QObject( 0 ),
+    : QObject( nullptr ),
       m_mapper( mapper )
 {
 }
@@ -35,26 +35,26 @@ ModelSignalMapperConnector::~ModelSignalMapperConnector()
 
 void ModelSignalMapperConnector::connectSignals( QAbstractItemModel* model )
 {
-    connect( model, SIGNAL( destroyed() ),                              this, SLOT( resetModel() ) );
-    connect( model, SIGNAL( columnsInserted( QModelIndex, int, int ) ), this, SLOT( columnsInserted( QModelIndex, int, int ) ) );
-    connect( model, SIGNAL( columnsRemoved( QModelIndex, int, int ) ),  this, SLOT( columnsRemoved( QModelIndex, int, int ) ) );
-    connect( model, SIGNAL( dataChanged( QModelIndex, QModelIndex ) ),  this, SLOT( dataChanged( QModelIndex, QModelIndex ) ) );
-    connect( model, SIGNAL( layoutChanged() ),                          this, SLOT( layoutChanged() ) );
-    connect( model, SIGNAL( modelReset() ),                             this, SLOT( modelReset() ) );
-    connect( model, SIGNAL( rowsInserted( QModelIndex, int, int ) ),    this, SLOT( rowsInserted( QModelIndex, int, int )) );
-    connect( model, SIGNAL( rowsRemoved( QModelIndex, int, int ) ),     this, SLOT( rowsRemoved( QModelIndex, int, int ) ) );
+    connect( model, SIGNAL(destroyed()),                              this, SLOT(resetModel()) );
+    connect( model, SIGNAL(columnsInserted(QModelIndex,int,int)), this, SLOT(columnsInserted(QModelIndex,int,int)) );
+    connect( model, SIGNAL(columnsRemoved(QModelIndex,int,int)),  this, SLOT(columnsRemoved(QModelIndex,int,int)) );
+    connect( model, SIGNAL(dataChanged(QModelIndex,QModelIndex)),  this, SLOT(dataChanged(QModelIndex,QModelIndex)) );
+    connect( model, SIGNAL(layoutChanged()),                          this, SLOT(layoutChanged()) );
+    connect( model, SIGNAL(modelReset()),                             this, SLOT(modelReset()) );
+    connect( model, SIGNAL(rowsInserted(QModelIndex,int,int)),    this, SLOT(rowsInserted(QModelIndex,int,int)) );
+    connect( model, SIGNAL(rowsRemoved(QModelIndex,int,int)),     this, SLOT(rowsRemoved(QModelIndex,int,int)) );
 }
 
 void ModelSignalMapperConnector::disconnectSignals( QAbstractItemModel* model )
 {
-    disconnect( model, SIGNAL( destroyed() ),                              this, SLOT( resetModel() ) );
-    disconnect( model, SIGNAL( columnsInserted( QModelIndex, int, int ) ), this, SLOT( columnsInserted( QModelIndex, int, int ) ) );
-    disconnect( model, SIGNAL( columnsRemoved( QModelIndex, int, int ) ),  this, SLOT( columnsRemoved( QModelIndex, int, int ) ) );
-    disconnect( model, SIGNAL( dataChanged( QModelIndex, QModelIndex ) ),  this, SLOT( dataChanged( QModelIndex, QModelIndex ) ) );
-    disconnect( model, SIGNAL( layoutChanged() ),                          this, SLOT( layoutChanged() ) );
-    disconnect( model, SIGNAL( modelReset() ),                             this, SLOT( modelReset() ) );
-    disconnect( model, SIGNAL( rowsInserted( QModelIndex, int, int ) ),    this, SLOT( rowsInserted( QModelIndex, int, int )) );
-    disconnect( model, SIGNAL( rowsRemoved( QModelIndex, int, int ) ),     this, SLOT( rowsRemoved( QModelIndex, int, int ) ) );
+    disconnect( model, SIGNAL(destroyed()),                              this, SLOT(resetModel()) );
+    disconnect( model, SIGNAL(columnsInserted(QModelIndex,int,int)), this, SLOT(columnsInserted(QModelIndex,int,int)) );
+    disconnect( model, SIGNAL(columnsRemoved(QModelIndex,int,int)),  this, SLOT(columnsRemoved(QModelIndex,int,int)) );
+    disconnect( model, SIGNAL(dataChanged(QModelIndex,QModelIndex)),  this, SLOT(dataChanged(QModelIndex,QModelIndex)) );
+    disconnect( model, SIGNAL(layoutChanged()),                          this, SLOT(layoutChanged()) );
+    disconnect( model, SIGNAL(modelReset()),                             this, SLOT(modelReset()) );
+    disconnect( model, SIGNAL(rowsInserted(QModelIndex,int,int)),    this, SLOT(rowsInserted(QModelIndex,int,int)) );
+    disconnect( model, SIGNAL(rowsRemoved(QModelIndex,int,int)),     this, SLOT(rowsRemoved(QModelIndex,int,int)) );
 }
 
 void ModelSignalMapperConnector::resetModel()
