@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef KCHARTMODELDATACACHE_H
@@ -95,7 +95,7 @@ namespace KChart
     {
     public:
         ModelDataCache()
-            : m_model( 0 ),
+            : m_model( nullptr ),
               m_connector( *this )
         {
         }
@@ -155,12 +155,12 @@ namespace KChart
 
         void setModel( QAbstractItemModel* model )
         {
-            if ( m_model != 0 )
+            if ( m_model != nullptr )
                 m_connector.disconnectSignals( m_model );
 
             m_model = model;
 
-            if ( m_model != 0 )
+            if ( m_model != nullptr )
                 m_connector.connectSignals( m_model );
 
             modelReset();
@@ -191,7 +191,7 @@ namespace KChart
 
         T fetchFromModel( int row, int column, int role ) const
         {
-            Q_ASSERT( m_model != 0 );
+            Q_ASSERT( m_model != nullptr );
 
             const QModelIndex index = m_model->index( row, column, m_rootIndex );
             const QVariant data = index.data( role );
@@ -204,9 +204,9 @@ namespace KChart
             return value;
         }
 
-        void columnsInserted( const QModelIndex& parent, int start, int end ) Q_DECL_OVERRIDE
+        void columnsInserted( const QModelIndex& parent, int start, int end ) override
         {
-            Q_ASSERT( m_model != 0 );
+            Q_ASSERT( m_model != nullptr );
             Q_ASSERT( parent.model() == m_model || !parent.isValid() );
 
             if ( parent != m_rootIndex )
@@ -225,9 +225,9 @@ namespace KChart
             }
         }
 
-        void columnsRemoved( const QModelIndex& parent, int start, int end ) Q_DECL_OVERRIDE
+        void columnsRemoved( const QModelIndex& parent, int start, int end ) override
         {
-            Q_ASSERT( m_model != 0 );
+            Q_ASSERT( m_model != nullptr );
             Q_ASSERT( parent.model() == m_model || !parent.isValid() );
 
             if ( parent != m_rootIndex )
@@ -245,11 +245,11 @@ namespace KChart
             }
         }
 
-        void dataChanged( const QModelIndex& topLeft, const QModelIndex& bottomRight ) Q_DECL_OVERRIDE
+        void dataChanged( const QModelIndex& topLeft, const QModelIndex& bottomRight ) override
         {
             if ( !m_model )
                 return;
-            Q_ASSERT( m_model != 0 );
+            Q_ASSERT( m_model != nullptr );
             Q_ASSERT( topLeft.parent() == bottomRight.parent() );
 
             if ( !topLeft.isValid() || !bottomRight.isValid() || topLeft.parent() != m_rootIndex )
@@ -277,17 +277,17 @@ namespace KChart
             }
         }
 
-        void layoutChanged() Q_DECL_OVERRIDE
+        void layoutChanged() override
         {
             modelReset();
         }
 
-        void modelReset() Q_DECL_OVERRIDE
+        void modelReset() override
         {
             m_data.clear();
             m_cacheValid.clear();
 
-            if ( m_model == 0 )
+            if ( m_model == nullptr )
                 return;
 
             m_data.fill( QVector< T >( m_model->columnCount( m_rootIndex ) ), m_model->rowCount( m_rootIndex ) );
@@ -297,9 +297,9 @@ namespace KChart
             Q_ASSERT( m_cacheValid.count() == m_model->rowCount( m_rootIndex ) );
         }
 
-        void rowsInserted( const QModelIndex& parent, int start, int end ) Q_DECL_OVERRIDE
+        void rowsInserted( const QModelIndex& parent, int start, int end ) override
         {
-            Q_ASSERT( m_model != 0 );
+            Q_ASSERT( m_model != nullptr );
             Q_ASSERT( parent.model() == m_model || !parent.isValid() );
 
             if ( parent != m_rootIndex || start >= m_model->rowCount(m_rootIndex) )
@@ -315,9 +315,9 @@ namespace KChart
             Q_ASSERT( m_cacheValid.count() == m_model->rowCount( m_rootIndex ) );
         }
 
-        void rowsRemoved( const QModelIndex& parent, int start, int end ) Q_DECL_OVERRIDE
+        void rowsRemoved( const QModelIndex& parent, int start, int end ) override
         {
-            Q_ASSERT( m_model != 0 );
+            Q_ASSERT( m_model != nullptr );
             Q_ASSERT( parent.model() == m_model || !parent.isValid() );
 
             if ( parent != m_rootIndex || start >= m_data.count() )
@@ -332,10 +332,10 @@ namespace KChart
             Q_ASSERT( m_cacheValid.count() == m_model->rowCount( m_rootIndex ) );
         }
 
-        void resetModel() Q_DECL_OVERRIDE
+        void resetModel() override
         {
             // no need to disconnect, this is a response to SIGNAL( destroyed() )
-            m_model = 0;
+            m_model = nullptr;
             modelReset();
         }
 
