@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "KChartRulerAttributes.h"
@@ -37,6 +37,7 @@ private:
     QPen tickMarkPen;
     QPen majorTickMarkPen;
     QPen minorTickMarkPen;
+    QPen rulerLinePen;
 
     bool majorTickMarkPenIsSet : 1;
     bool minorTickMarkPenIsSet : 1;
@@ -259,7 +260,7 @@ RulerAttributes & RulerAttributes::operator=( const RulerAttributes& r )
 
 RulerAttributes::~RulerAttributes()
 {
-    delete _d; _d = 0;
+    delete _d; _d = nullptr;
 }
 
 bool RulerAttributes::operator==( const RulerAttributes& r ) const
@@ -271,6 +272,7 @@ bool RulerAttributes::operator==( const RulerAttributes& r ) const
                    minorTickMarkPenIsSet() == r.minorTickMarkPenIsSet() &&
                    showMajorTickMarks() == r.showMajorTickMarks() &&
                    showMinorTickMarks() == r.showMinorTickMarks() &&
+                   rulerLinePen() == r.rulerLinePen() &&
                    showRulerLine() == r.showRulerLine() &&
                    majorTickMarkLengthIsSet() == r.majorTickMarkLengthIsSet() &&
                    minorTickMarkLengthIsSet() == r.minorTickMarkLengthIsSet() &&
@@ -289,6 +291,16 @@ bool RulerAttributes::operator==( const RulerAttributes& r ) const
     return true;
 }
 
+void RulerAttributes::setRulerLinePen(const QPen &pen)
+{
+    d->rulerLinePen = pen;
+}
+
+QPen RulerAttributes::rulerLinePen() const
+{
+    return d->rulerLinePen;
+}
+
 void RulerAttributes::setShowRulerLine( bool show )
 {
     d->showRulerLine = show;
