@@ -14,11 +14,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef KCHARTTHREEDLINESATTRIBUTES_P_H
-#define KCHARTTHREEDLINESATTRIBUTES_P_H
+#ifndef KCHARTTHREEDLINEATTRIBUTES_P_H
+#define KCHARTTHREEDLINEATTRIBUTES_P_H
 
 //
 //  W A R N I N G
@@ -58,4 +58,4 @@ KCHART_DERIVED_PRIVATE_FOOTER(ThreeDLineAttributes, AbstractThreeDAttributes)
 }
 
 
-#endif // KCHARTTHREEDLINESATTRIBUTES_P_H
+#endif // KCHARTTHREEDLINEATTRIBUTES_P_H
