@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "KChartRadarDiagram.h"
@@ -55,9 +55,6 @@ void RadarDiagram::init()
 }
 
 
-/**
-  * Creates an exact copy of this diagram.
-  */
 RadarDiagram * RadarDiagram::clone() const
 {
     RadarDiagram* newDiagram = new RadarDiagram( new Private( *d ) );
@@ -186,7 +183,6 @@ void RadarDiagram::paint( PaintContext* ctx,
     labelFont.setPointSizeF( labelFontSize );
     const QFontMetricsF metric( labelFont );
     const qreal labelHeight = metric.height();
-    QPointF offset;
     QRectF destRect = ctx->rectangle();    
     if ( ta.isVisible() )
     {        
@@ -205,7 +201,7 @@ void RadarDiagram::paint( PaintContext* ctx,
                 QModelIndex index = model()->index( iRow, iCol, rootIndex() ); // checked
                 const qreal value = model()->data( index ).toReal();
                 QPointF point = scaleToRealPosition( QPointF( value, iRow ), ctx->rectangle(), destRect, *ctx->coordinatePlane() );
-                d->addLabel( &d->labelPaintCache, index, 0, PositionPoints( point ),
+                d->addLabel( &d->labelPaintCache, index, nullptr, PositionPoints( point ),
                              Position::Center, Position::Center, value );
             }
         }
