@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef KCHARTTERNARYCOORDINATEPLANE_P_H
@@ -57,7 +57,7 @@ namespace KChart {
             // grid is delete in base class dtor
         }
 
-        void initialize() Q_DECL_OVERRIDE
+        void initialize() override
         {
             grid = new TernaryGrid();
             xUnit = 0.0;
