@@ -136,7 +136,7 @@ void ForwardingProxyModel::sourceModelReset()
 void ForwardingProxyModel::sourceLayoutAboutToBeChanged()
 {
   //qDebug() << "ForwardingProxyModel::sourceLayoutAboutToBeChanged()";
-    emit layoutAboutToBeChanged();
+    Q_EMIT layoutAboutToBeChanged();
 }
 
 
@@ -151,7 +151,7 @@ void ForwardingProxyModel::sourceLayoutChanged()
 void ForwardingProxyModel::sourceDataChanged( const QModelIndex& from, const QModelIndex& to )
 {
   //qDebug() << "ForwardingProxyModel::sourceDataChanged("<<from<<to<<")";
-    emit dataChanged( mapFromSource( from ), mapFromSource( to ) );
+    Q_EMIT dataChanged( mapFromSource( from ), mapFromSource( to ) );
 }
 
 
