@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "kganttlistviewrowcontroller.h"
@@ -27,12 +27,7 @@
 
 using namespace KGantt;
 
-/*!\class TreeViewRowController
- * This is an implementation of AbstractRowController that
- * aligns a gantt view with a QListView. Provided for
- * convenience for users who want to use View with QListView
- * instead of QTreeView.
- */
+
 
 ListViewRowController::ListViewRowController( QListView* lv, QAbstractProxyModel* proxy )
   : _d( new Private(lv,proxy) )
@@ -41,7 +36,7 @@ ListViewRowController::ListViewRowController( QListView* lv, QAbstractProxyModel
 
 ListViewRowController::~ListViewRowController()
 {
-    delete _d; _d = 0;
+    delete _d; _d = nullptr;
 }
 
 #define d d_func()
