@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef KGANTTVIEW_P_H
@@ -52,7 +52,7 @@ namespace KGantt {
     class KGanttTreeView : public QTreeView {
         Q_OBJECT
     public:
-        explicit KGanttTreeView( QAbstractProxyModel* proxy, QWidget* parent=0 );
+        explicit KGanttTreeView( QAbstractProxyModel* proxy, QWidget* parent = nullptr );
         virtual ~KGanttTreeView();
 
         AbstractRowController* rowController() { return &m_controller; }
