@@ -18,6 +18,8 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
+#ifndef TESTKGANTTCONSTRAINTMODEL_H
+#define TESTKGANTTCONSTRAINTMODEL_H
 
 #include <QtTest>
 #include <QStandardItemModel>
@@ -34,3 +36,4 @@ private Q_SLOTS:
     void cleanupTestCase();
     void testModel();
 };
+#endif
