@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef __KDAB__UNITTEST__TEST_H__
@@ -145,10 +145,10 @@ namespace UnitTest {
   template <typename T_Test>
   class GenericFactory : public TestFactory {
   public:
-    GenericFactory( const char * group=0 ) {
+    GenericFactory( const char * group = nullptr ) {
       TestRegistry::instance()->registerTestFactory( this, group );
     }
-    Test * create() const Q_DECL_OVERRIDE { return new T_Test(); }
+    Test * create() const override { return new T_Test(); }
   };
 
 }
@@ -189,7 +189,7 @@ namespace UnitTest {
         class Class##Test : public KDAB::UnitTest::Test {  \
         public:                                                 \
             Class##Test() : Test( #Namespace "::" #Class ) {}    \
-            void run() Q_DECL_OVERRIDE;                          \
+            void run() override;                          \
         };                                                      \
     }                                                           \
     KDAB_EXPORT_SCOPED_UNITTEST( Namespace, Class##Test, Group ) \
