@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef KDAB_NO_UNIT_TESTS
@@ -36,7 +36,7 @@ KDAB::UnitTest::TestRegistry::TestRegistry()
 
 KDAB::UnitTest::TestRegistry::~TestRegistry() {}
 
-KDAB::UnitTest::TestRegistry * KDAB::UnitTest::TestRegistry::mSelf = 0;
+KDAB::UnitTest::TestRegistry * KDAB::UnitTest::TestRegistry::mSelf = nullptr;
 
 // static
 KDAB::UnitTest::TestRegistry * KDAB::UnitTest::TestRegistry::instance() {
@@ -47,7 +47,7 @@ KDAB::UnitTest::TestRegistry * KDAB::UnitTest::TestRegistry::instance() {
 
 // static
 void KDAB::UnitTest::TestRegistry::deleteInstance() {
-    delete mSelf; mSelf = 0;
+    delete mSelf; mSelf = nullptr;
 }
 
 void KDAB::UnitTest::TestRegistry::registerTestFactory( const TestFactory * tf, const char * group ) {
