@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <QApplication>
@@ -43,31 +43,31 @@ public:
         m_model = model;
     }
 
-    /*reimp*/int headerHeight() const Q_DECL_OVERRIDE { return 40; }
+    /*reimp*/int headerHeight() const override { return 40; }
 
-    /*reimp*/ bool isRowVisible( const QModelIndex& ) const Q_DECL_OVERRIDE { return true;}
-    /*reimp*/ bool isRowExpanded( const QModelIndex& ) const Q_DECL_OVERRIDE { return false; }
-    /*reimp*/ KGantt::Span rowGeometry( const QModelIndex& idx ) const Q_DECL_OVERRIDE
+    /*reimp*/ bool isRowVisible( const QModelIndex& ) const override { return true;}
+    /*reimp*/ bool isRowExpanded( const QModelIndex& ) const override { return false; }
+    /*reimp*/ KGantt::Span rowGeometry( const QModelIndex& idx ) const override
     {
         qDebug() << "rowGeometry(" << idx.row()<<")";
         return KGantt::Span( idx.row()*ROW_HEIGHT, ROW_HEIGHT );
     }
-    /*reimp*/ int maximumItemHeight() const Q_DECL_OVERRIDE {
+    /*reimp*/ int maximumItemHeight() const override {
         return ROW_HEIGHT/2;
     }
-    /*reimp*/ int totalHeight() const Q_DECL_OVERRIDE {
+    /*reimp*/ int totalHeight() const override {
         return m_model.isNull()?0:m_model->rowCount()*ROW_HEIGHT;
     }
 
-    /*reimp*/ QModelIndex indexAt( int height ) const Q_DECL_OVERRIDE {
+    /*reimp*/ QModelIndex indexAt( int height ) const override {
         return m_model->index( height/ROW_HEIGHT, 0 );
     }
 
-    /*reimp*/ QModelIndex indexBelow( const QModelIndex& idx ) const Q_DECL_OVERRIDE {
+    /*reimp*/ QModelIndex indexBelow( const QModelIndex& idx ) const override {
         if ( !idx.isValid() )return QModelIndex();
         return idx.model()->index( idx.row()+1, idx.column(), idx.parent() );
     }
-    /*reimp*/ QModelIndex indexAbove( const QModelIndex& idx ) const Q_DECL_OVERRIDE {
+    /*reimp*/ QModelIndex indexAbove( const QModelIndex& idx ) const override {
         if ( !idx.isValid() )return QModelIndex();
         return idx.model()->index( idx.row()-1, idx.column(), idx.parent() );
     }
@@ -78,7 +78,7 @@ const int MyRowController::ROW_HEIGHT = 30;
 
 class MyStandardItemModel : public QStandardItemModel {
 public:
-    /*reimp*/bool setData( const QModelIndex& idx, const QVariant& value, int role ) Q_DECL_OVERRIDE
+    /*reimp*/bool setData( const QModelIndex& idx, const QVariant& value, int role ) override
     {
         //qDebug() << "MyStandardItemModel::setData("<<idx<< value<<role<<")";
         return QStandardItemModel::setData( idx, value, role );
@@ -128,8 +128,8 @@ int main( int argc, char** argv ) {
             item->setData( KGantt::TypeTask, KGantt::ItemTypeRole );
             item->setData( QDateTime::currentDateTime().addDays( 2*j ).addMSecs( 100000*i ), KGantt::StartTimeRole );
             item->setData( QDateTime::currentDateTime().addDays( 2*j+1 ).addMSecs( 100000*i ), KGantt::EndTimeRole );
-            item->setData( qVariantFromValue<int>( random_alignment() ), Qt::TextAlignmentRole );
-			item->setData( qVariantFromValue<int>( random_position()), KGantt::TextPositionRole );
+            item->setData( QVariant::fromValue<int>( random_alignment() ), Qt::TextAlignmentRole );
+			item->setData( QVariant::fromValue<int>( random_position()), KGantt::TextPositionRole );
             item->setFlags( item->flags() & ~Qt::ItemIsSelectable );
             //  item->appendColumn( QList<QStandardItem*>() << colitem );
             //}
@@ -142,8 +142,8 @@ int main( int argc, char** argv ) {
     view->setModel( &model );
 #if 0
     QPushButton* pb = new QPushButton( QObject::tr( "Reset" ) );
-    QObject::connect( pb, SIGNAL( clicked() ),
-                      &model, SIGNAL( modelReset() ) );
+    QObject::connect( pb, SIGNAL(clicked()),
+                      &model, SIGNAL(modelReset()) );
     pb->show();
 #endif
     return app.exec();
