@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <QApplication>
@@ -35,7 +35,7 @@ class MyTaskModel : public QAbstractTableModel {
     };
     QList<Task> m_tasks;
 public:
-    MyTaskModel( QObject* parent=0 )
+    MyTaskModel( QObject* parent = nullptr )
         : QAbstractTableModel( parent )
     {
         Task task;
@@ -57,13 +57,13 @@ public:
         m_tasks.push_back( task );
     }
 
-    /*reimp*/int rowCount( const QModelIndex& index = QModelIndex() ) const Q_DECL_OVERRIDE {
+    /*reimp*/int rowCount( const QModelIndex& index = QModelIndex() ) const override {
         return index.isValid()?0:m_tasks.size();
     }
-    /*reimp*/int columnCount( const QModelIndex& index = QModelIndex() ) const Q_DECL_OVERRIDE {
+    /*reimp*/int columnCount( const QModelIndex& index = QModelIndex() ) const override {
         return index.isValid()?0:4;
     }
-    /*reimp*/QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const Q_DECL_OVERRIDE
+    /*reimp*/QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const override
     {
         if ( index.isValid() && index.row() < rowCount() && index.column() < columnCount() ) {
             switch ( index.column() ) {
@@ -167,7 +167,7 @@ int main( int argc, char** argv )
     view->show();
 
     /* After 5 seconds, move row 1 to pos 0: */
-    QTimer::singleShot( 5000, new MoveHelper( &model, &constraints, view, 1, 0 ), SLOT( deleteLater() ) );
+    QTimer::singleShot( 5000, new MoveHelper( &model, &constraints, view, 1, 0 ), SLOT(deleteLater()) );
 
     return app.exec();
 }
